# This specfile is licensed under:
# SPDX-License-Identifier: MIT
# License text: https://spdx.org/licenses/MIT.html
# SPDX-FileCopyrightText: Fedora Project Authors
# SPDX-FileCopyrightText: 2022 Maxwell G <gotmax@e.email>

%bcond_with tests

Name:           python-flit-core
Version:        3.8.0
Release:        1%{?dist}
Summary:        Simplified packaging of Python modules

License:        BSD-3-Clause
URL:            https://github.com/pypa/flit
Source0:        %{pypi_source flit_core}
# The README was in the sdist for the previous release,
# but it's not in this one :(.
Source1:        %{url}/raw/%{version}/flit_core/README.rst#/README.rst.upstream
# Add custom tmp_path pytest fixture
# RHEL 8's old pytest does not support this fixture.
Patch0:         0001-Add-custom-tmp_path-pytest-fixture.patch

BuildArch:      noarch
BuildRequires:  python%{python3_pkgversion}-devel
# Pip is needed for %%py3_install_wheel
BuildRequires:  python%{python3_pkgversion}-pip
BuildRequires:  python%{python3_pkgversion}-tomli
%if %{with tests}
BuildRequires:  python%{python3_pkgversion}-pytest
BuildRequires:  python%{python3_pkgversion}-testpath
%endif


%global _description %{expand:
Flit is a simple way to put Python packages and modules on PyPI.

Flit only creates packages in the new 'wheel' format. People using older
versions of pip (<1.5) or easy_install will not be able to install them.

Flit packages a single importable module or package at a time, using the import
name as the name on PyPI. All sub-packages and data files within a package are
included automatically.

Flit requires Python 3, but you can use it to distribute modules for Python 2,
so long as they can be imported on Python 3.}


%description %_description

%package -n     python%{python3_pkgversion}-flit-core
Summary:        %{summary}
# We manually specify this, because it's bundled upstream and not in the metadata
Requires:       python%{python3_pkgversion}-tomli

%description -n python%{python3_pkgversion}-flit-core %_description


%prep
%autosetup -p1 -n flit_core-%{version}
cp %{SOURCE1} .
mv README.rst{.upstream,}

# Remove vendored tomli that flit_core includes to solve the circular dependency.
# (flit_core requires tomli, but flit_core is needed to build tomli).
# We don't use this, as python3-tomli already has its own bootstrap bcond
# to build without flit_core.
rm -rf flit_core/vendor


%build
%python3 -m flit_core.wheel


%install
%py3_install_wheel flit_core-%{version}-py3-none-any.whl

# don't ship tests in flit_core package
# if upstream decides to change the installation, it can be removed:
# https://github.com/takluyver/flit/issues/403
rm -r %{buildroot}%{python3_sitelib}/flit_core/tests/


%check
%py3_check_import flit_core
%if %{with tests}
%pytest
%endif


%files -n python%{python3_pkgversion}-flit-core
%doc README.rst
%license LICENSE
%{python3_sitelib}/flit_core/
%{python3_sitelib}/flit_core-%{version}.dist-info/


%changelog
* Sat Nov 12 2022 Maxwell G <gotmax@e.email> - 3.8.0-1
- Update to 3.8.0.

* Thu Oct 06 2022 Maxwell G <gotmax@e.email> - 3.7.1-1
- Initial EPEL 8 package (rhbz#2133111).
